# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-07-03 17:20
from __future__ import unicode_literals

import django.contrib.gis.db.models.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('topology', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='topologyerror',
            name='geom',
            field=django.contrib.gis.db.models.fields.GeometryField(null=True, srid=4326),
        ),
    ]
